@@ -1,4 +1,4 @@
-# $Id: emoncms.py 1343 2015-07-24 23:49:19Z mwall $
+# $Id: emoncms.py 1383 2015-10-31 15:59:53Z mwall $
 # Copyright 2013-2014 Matthew Wall
 
 """
@@ -64,7 +64,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.11"
+VERSION = "0.13"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -177,6 +177,8 @@ class EmonCMS(weewx.restx.StdRESTbase):
         site_dict.setdefault('append_units_label', True)
         site_dict.setdefault('augment_record', True)
         site_dict.setdefault('obs_to_upload', 'all')
+        site_dict['append_units_label'] = to_bool(site_dict.get('append_units_label'))
+        site_dict['augment_record'] = to_bool(site_dict.get('augment_record'))
 
         usn = site_dict.get('unit_system', None)
         if usn is not None:
